@@ -97,6 +97,7 @@ __TLDS = R'(?i:{possible_tld})(?!(?:{dealbreakers}))'.format(
         R'[a-z]',
         R'[A-Za-z]{3}',
         R'\.\w\w',
+        R'\([\'"\w)]'
     ])
 )
 
@@ -117,9 +118,9 @@ pattern_domain_df = format_domain_defang.format(repeat='{0,20}', tlds=__TLDS)
 
 pattern_version = '|'.join('.' * k + 'version' + '.' * (10 - k) for k in range(10))
 
-pattern_ocet = R'(?:[12]\d\d|[1-9]?\d)'
-pattern_ipv4 = R'(?<!\.|\d)(?:{o}\.){{3}}{o}(?![\d\.])'.format(o=pattern_ocet)
-pattern_ipv4_df = R'(?:{o}{d}){{3}}{o}'.format(o=pattern_ocet, d=R'(?:\[\.\]|\.)')
+pattern_octet = R'(?:[12]\d\d|[1-9]?\d)'
+pattern_ipv4 = R'(?<!\.|\d)(?:{o}\.){{3}}{o}(?![\d\.])'.format(o=pattern_octet)
+pattern_ipv4_df = R'(?:{o}{d}){{3}}{o}'.format(o=pattern_octet, d=R'(?:\[\.\]|\.)')
 
 pattern_socket = '(?:{ip}|{d})(?::\\d{{2,5}})'.format(ip=pattern_ipv4, d=pattern_domain)
 pattern_hostname = pattern_socket + '?'
@@ -152,8 +153,8 @@ pattern_url_df = ''.join([
 pattern_email = R'(?:[a-zA-Z0-9_\.\+\-]{{1,256}}?)@(?:{})'.format(pattern_domain)
 pattern_guid = R'(?:\b|\{)[0-9A-Fa-f]{8}(?:\-[0-9A-Fa-f]{4}){3}\-[0-9A-Fa-f]{12}(?:\}|\b)'
 
-pattern_win_path_nospace = R'[-\w+,.;@\]\[\^`~]+'  # R'[^/\\:"<>|\s\x7E-\xFF\x00-\x1F\xAD]+'
-pattern_win_path_element = R'(?:{n} ){{0,4}}{n}'.format(n=pattern_win_path_nospace)
+pattern_pathpart_nospace = R'[-\w+,.;@\]\[\^`~]+'  # R'[^/\\:"<>|\s\x7E-\xFF\x00-\x1F\xAD]+'
+pattern_win_path_element = R'(?:{n} ){{0,4}}{n}'.format(n=pattern_pathpart_nospace)
 pattern_win_env_variable = R'%[a-zA-Z][a-zA-Z0-9_\-\(\)]{2,}%'
 
 pattern_win_path = R'(?:{s})(?P<pathsep>[\\\/])(?:{p}(?P=pathsep))*{p}\b'.format(
@@ -166,6 +167,12 @@ pattern_win_path = R'(?:{s})(?P<pathsep>[\\\/])(?:{p}(?P=pathsep))*{p}\b'.format
     p=pattern_win_path_element
 )
 
+pattern_nix_path = R'\b/?(?:{n}/){{2,}}{n}\b'.format(n=pattern_pathpart_nospace)
+pattern_path = R'(?:{nix})|(?:{win})'.format(
+    nix=pattern_nix_path,
+    win=pattern_win_path
+)
+
 pattern_hexline = R'(?:{s}+\s+)?\s*{h}(?:\s+{s}+)?'.format(
     h=tokenize(
         R'(?:0x)?[0-9a-f]{2}h?',
@@ -269,7 +276,7 @@ class indicators(PatternEnum):
     "A pattern matching PEM encoded cryptographic parameters"
     xmr = alphabet('[1-9A-HJ-NP-Za-km-z]', prefix='4[0-9AB]', at_least=93, at_most=93)
     "Monero addresses"
-    path = pattern(pattern_win_path)
+    path = pattern(pattern_path)
     "Windows and Linux path names"
     evar = pattern(pattern_win_env_variable)
     "Windows environment variables, i.e. something like `%APPDATA%`"
